"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStopwatch = void 0;
const vue_1 = require("vue");
const utils_1 = require("./utils");
const hooks_1 = require("./hooks");
const epochSeconds = () => new Date().getTime();
const useStopwatch = (autoStart = true, offsetTimestamp) => {
    const passedSeconds = vue_1.ref(utils_1.Time.getSecondsFromExpiry(offsetTimestamp, true) || 0);
    const prevTime = vue_1.ref(epochSeconds());
    const seconds = vue_1.ref(passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(prevTime.value || 0, true));
    const isRunning = vue_1.ref(autoStart);
    hooks_1.useInterval(() => {
        seconds.value =
            passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(prevTime.value, true);
    }, isRunning.value ? 1000 : false);
    function start() {
        const newPrevTime = epochSeconds();
        prevTime.value = newPrevTime;
        isRunning.value = true;
        seconds.value =
            passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(newPrevTime, true);
    }
    function pause() {
        passedSeconds.value = seconds.value;
        isRunning.value = false;
    }
    function reset(offset = 0, newAutoStart = true) {
        const newPassedSeconds = utils_1.Time.getSecondsFromExpiry(offset, true) || 0;
        const newPrevTime = epochSeconds();
        prevTime.value = newPrevTime;
        passedSeconds.value = newPassedSeconds;
        isRunning.value = newAutoStart;
        seconds.value =
            newPassedSeconds + utils_1.Time.getSecondsFromPrevTime(newPrevTime, true);
    }
    return Object.assign(Object.assign({}, utils_1.Time.getTimeFromSeconds(seconds.value)), { start,
        pause,
        reset,
        isRunning });
};
exports.useStopwatch = useStopwatch;
//# sourceMappingURL=useStopwatch.js.map