"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTimer = void 0;
// import { useState } from 'react';
const vue_1 = require("vue");
const utils_1 = require("./utils");
const hooks_1 = require("./hooks");
const DEFAULT_DELAY = 1000;
function getDelayFromExpiryTimestamp(expiryTimestamp) {
    if (!utils_1.Validate.expiryTimestamp(expiryTimestamp)) {
        return null;
    }
    const seconds = utils_1.Time.getSecondsFromExpiry(expiryTimestamp);
    const extraMilliSeconds = Math.floor((seconds - Math.floor(seconds)) * 1000);
    return extraMilliSeconds > 0 ? extraMilliSeconds : DEFAULT_DELAY;
}
const useTimer = (expiry = 60, autoStart = true) => {
    const expiryTimestamp = vue_1.ref(expiry);
    const seconds = vue_1.ref(utils_1.Time.getSecondsFromExpiry(expiryTimestamp.value));
    const isRunning = vue_1.ref(autoStart);
    const isExpired = vue_1.ref(false);
    const didStart = vue_1.ref(autoStart);
    const delay = vue_1.ref(getDelayFromExpiryTimestamp(expiryTimestamp.value));
    function _handleExpire() {
        isExpired.value = true;
        isRunning.value = false;
        delay.value = null;
    }
    function pause() {
        isRunning.value = false;
    }
    function restart(newExpiryTimestamp, newAutoStart = true) {
        delay.value = getDelayFromExpiryTimestamp(newExpiryTimestamp);
        didStart.value = newAutoStart;
        isExpired.value = false;
        isRunning.value = newAutoStart;
        expiryTimestamp.value = newExpiryTimestamp;
        seconds.value = utils_1.Time.getSecondsFromExpiry(newExpiryTimestamp);
    }
    function resume() {
        const time = new Date();
        time.setMilliseconds(time.getMilliseconds() + seconds.value * 1000);
        restart(time.getTime());
    }
    function start() {
        if (didStart) {
            seconds.value = utils_1.Time.getSecondsFromExpiry(expiryTimestamp.value);
            isRunning.value = true;
        }
        else {
            resume();
        }
    }
    hooks_1.useInterval(() => {
        if (delay.value !== DEFAULT_DELAY) {
            delay.value = DEFAULT_DELAY;
        }
        const secondsValue = utils_1.Time.getSecondsFromExpiry(expiryTimestamp.value);
        seconds.value = secondsValue;
        if (secondsValue <= 0) {
            _handleExpire();
        }
    }, isRunning.value ? delay.value : null);
    return Object.assign(Object.assign({}, utils_1.Time.getTimeFromSeconds(seconds.value)), { start,
        pause,
        resume,
        restart,
        isRunning,
        isExpired });
};
exports.useTimer = useTimer;
//# sourceMappingURL=useTimer.js.map